@@ -19,15 +19,16 @@ from .pssdfixedrank import PSSDFixedRank
 def _register_manifold(module, tensor_name, cls, *args):
     tensor = getattr(module, tensor_name)
     M = cls(tensor.size(), *args).to(device=tensor.device, dtype=tensor.dtype)
-    P.register_parametrization(module, tensor_name, M)
 
     # Initialize without checking in manifold
     X = M.sample()
-    param_list = module.parametrizations[tensor_name]
-    with torch.no_grad():
-        for m in reversed(param_list):
-            X = m.right_inverse(X, check_in_manifold=False)
-        param_list.original.copy_(X)
+    if not P.is_parametrized(module, tensor_name):
+        with torch.no_grad():
+            tensor.copy_(X)
+    else:
+        setattr(module, tensor_name, X)
+
+    P.register_parametrization(module, tensor_name, M, unsafe=True)
 
     return module
 
@@ -138,7 +139,7 @@ def orthogonal(module, tensor_name="weight", triv="expm"):
 
         >>> layer = nn.Conv2d(20, 40, 3, 3)  # Make the kernels orthogonal
         >>> geotorch.orthogonal(layer, "weight")
-        >>> torch.norm(layer.weight.transpose(-2, -1) @ layer.weight - torch.eye(3,3).repeat(40,20,1,1))
+        >>> torch.norm(layer.weight.transpose(-2, -1) @ layer.weight - torch.eye(3,3))
         tensor(1.2225e-05)
 
     Args:
@@ -224,7 +225,7 @@ def grassmannian(module, tensor_name="weight", triv="expm"):
 
         >>> layer = nn.Conv2d(20, 40, 3, 3)  # Make the kernels represent subspaces
         >>> geotorch.grassmannian(layer, "weight")
-        >>> torch.norm(layer.weight.transpose(-2, -1) @ layer.weight - torch.eye(3,3).repeat(40,20,1,1))
+        >>> torch.norm(layer.weight.transpose(-2, -1) @ layer.weight - torch.eye(3,3))
         tensor(8.3796-06)
 
     Args:
